pub struct WebSocketHandle {
pub id: String,
pub url: String,
pub connected: Arc<Mutex<bool>>,
}Expand description
WebSocket connection handle
Fields
id: StringUnique connection ID
url: StringURL of the WebSocket server
connected: Arc<Mutex<bool>>Whether the connection is active
Implementations
Sourceimpl WebSocketHandle
impl WebSocketHandle
Sourcepub async fn send_text(&self, _message: String) -> Result<(), WebSocketError>
pub async fn send_text(&self, _message: String) -> Result<(), WebSocketError>
Send a text message through the WebSocket
Errors
Returns WebSocketError::SendFailed if the connection is not active or sending fails.
Sourcepub async fn send_binary(&self, _data: Vec<u8>) -> Result<(), WebSocketError>
pub async fn send_binary(&self, _data: Vec<u8>) -> Result<(), WebSocketError>
Send binary data through the WebSocket
Errors
Returns WebSocketError::SendFailed if the connection is not active or sending fails.