pub enum TerminalControlMsg {
HideCursor,
ShowCursor,
EnterAltScreen,
ExitAltScreen,
SetWindowTitle(String),
EnableMouseCellMotion,
EnableMouseAllMotion,
DisableMouse,
ClearScreen,
ClearLine,
}Expand description
Special message types for terminal control
Variants
HideCursor
Hide the terminal cursor from view
ShowCursor
Show the terminal cursor
EnterAltScreen
Enter the alternate screen buffer (like vim/less use)
ExitAltScreen
Exit the alternate screen buffer and return to main screen
SetWindowTitle(String)
Set the terminal window title to the given string
EnableMouseCellMotion
Enable mouse tracking for cell motion (only when button pressed)
EnableMouseAllMotion
Enable mouse tracking for all motion events (including hover)
DisableMouse
Disable all mouse tracking
ClearScreen
Clear the entire screen
ClearLine
Clear the current line